#setwd("/Volumes/Macintosh HD 2/MDAnderson/MyPapers/TopNorm/SupplementaryInfo")

# this code requires the SuperCurve package which can be downloaded at
# http://bioinformatics.mdanderson.org/Software/OOMPA/#supercurve
require(SuperCurve)

source('spatialNorm.R') # this function performs topographical normalizatoin
# NOTE: this function requires the "mgcv" package


load(file='ReplicateMarkers.Rda') # file contains information about the replicates
                                  # on the right and left sides of the array

rppa <- RPPA('CASP3Clvd.txt') # read in raw data

# perform topographical normalization
#  The results of the "spatialNorm" is another RPPA object
#  but with new columns:  Spatial.NormOne for the single surface
#  correction and Spatial.Norm for the nested surface correction

rppa2 <- spatialNorm(rppa,'Mean.Net',nDilut=5,negcon=list("Buffer"),poscon=list("contrl"),plot.surface=T)



######################
# function to compute Lin's concordance coefficient
concord <- function(x1,x2) {
	n <- length(x1)
	xbar1 <- mean(x1,na.rm=T)
	xbar2 <- mean(x2,na.rm=T)
	s1 <- sum((x1-xbar1)^2,na.rm=T)/n
	s2 <- sum((x2-xbar2)^2,na.rm=T)/n
	s12 <- sum((x1-xbar1)*(x2-xbar2),na.rm=T)/n
	pc <- (2*s12)/(s1+s2+(xbar1-xbar2)^2)
	return(pc)
}

maplot <- function(x,y,...) {
	a <- (x+y)/2
	m <- (y-x)
	plot(a,m,xlab='Average',ylab='Difference',...) 
	abline(h=0,col='red')
}

par(mfrow=c(2,2))

maplot(rppa2@data$Mean.Total[left],rppa2@data$Mean.Total[right])
title('No Adjustment')
maplot(rppa2@data$Mean.Net[left],rppa2@data$Mean.Net[right])
title('Background Subtraction')  
maplot(rppa2@data$Spatial.NormOne[left],rppa2@data$Spatial.NormOne[right])
title('One Surface Correction')
maplot(rppa2@data$Spatial.Norm[left],rppa2@data$Spatial.Norm[right])
title('Multi Surface Correction')

concord(rppa2@data$Mean.Total[left],rppa2@data$Mean.Total[right])
concord(rppa2@data$Mean.Net[left],rppa2@data$Mean.Net[right])
concord(rppa2@data$Spatial.NormOne[left],rppa2@data$Spatial.NormOne[right])
concord(rppa2@data$Spatial.Norm[left],rppa2@data$Spatial.Norm[right])




